@@ -266,10 +266,10 @@ void DailymotionPlaylistWindow::playPlaylist() {
         return;
     }
     
-    QList<Video*> list;
+    QList<CTVideo*> list;
     
     for (int i = 0; i < m_model->rowCount(); i++) {
-        if (Video *video = m_model->get(i)) {
+        if (CTVideo *video = m_model->get(i)) {
             list << video;
         }
     }
